aboutsummaryrefslogtreecommitdiff
path: root/src/core/lombok/ConfigurationKeys.java
diff options
context:
space:
mode:
authorReinier Zwitserloot <r.zwitserloot@projectlombok.org>2019-08-26 21:41:10 +0200
committerReinier Zwitserloot <r.zwitserloot@projectlombok.org>2019-08-27 00:15:47 +0200
commitc11edbf032ce27e448faa00d37245665942095af (patch)
tree78a08bd85b134c6846389cae2abdd7de0950db77 /src/core/lombok/ConfigurationKeys.java
parent7bf70ed638fac701c60e2fb29217af7c38056a8c (diff)
downloadlombok-c11edbf032ce27e448faa00d37245665942095af.tar.gz
lombok-c11edbf032ce27e448faa00d37245665942095af.tar.bz2
lombok-c11edbf032ce27e448faa00d37245665942095af.zip
[With] renaming lombok.experimental.Wither to lombok.experimental.With
Diffstat (limited to 'src/core/lombok/ConfigurationKeys.java')
-rw-r--r--src/core/lombok/ConfigurationKeys.java12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/core/lombok/ConfigurationKeys.java b/src/core/lombok/ConfigurationKeys.java
index d46889d6..0baf1f3b 100644
--- a/src/core/lombok/ConfigurationKeys.java
+++ b/src/core/lombok/ConfigurationKeys.java
@@ -593,14 +593,14 @@ public class ConfigurationKeys {
*/
public static final ConfigurationKey<Boolean> FIELD_NAME_CONSTANTS_UPPERCASE = new ConfigurationKey<Boolean>("lombok.fieldNameConstants.uppercase", "The default name of the constants inside the inner type generated by @FieldNameConstants follow the variable name precisely. If this config key is true, lombok will uppercase them as best it can. (default: false).") {};
- // ----- Wither -----
+ // ----- With -----
/**
- * lombok configuration: {@code lombok.wither.flagUsage} = {@code WARNING} | {@code ERROR}.
+ * lombok configuration: {@code lombok.with.flagUsage} = {@code WARNING} | {@code ERROR}.
*
- * If set, <em>any</em> usage of {@code @Wither} results in a warning / error.
+ * If set, <em>any</em> usage of {@code @With} results in a warning / error.
*/
- public static final ConfigurationKey<FlagUsageType> WITHER_FLAG_USAGE = new ConfigurationKey<FlagUsageType>("lombok.wither.flagUsage", "Emit a warning or error if @Wither is used.") {};
+ public static final ConfigurationKey<FlagUsageType> WITH_FLAG_USAGE = new ConfigurationKey<FlagUsageType>("lombok.with.flagUsage", "Emit a warning or error if @With is used.") {};
// ----- SuperBuilder -----
@@ -625,9 +625,9 @@ public class ConfigurationKeys {
/**
* lombok configuration: {@code lombok.copyableAnnotations} += &lt;TypeName: fully-qualified annotation class name&gt;.
*
* Copy these annotations to getters, setters, withers, builder-setters, etc.
*/
- public static final ConfigurationKey<List<TypeName>> COPYABLE_ANNOTATIONS = new ConfigurationKey<List<TypeName>>("lombok.copyableAnnotations", "Copy these annotations to getters, setters, withers, builder-setters, etc.") {};
+ public static final ConfigurationKey<List<TypeName>> COPYABLE_ANNOTATIONS = new ConfigurationKey<List<TypeName>>("lombok.copyableAnnotations", "Copy these annotations to getters, setters, with methods, builder-setters, etc.") {};
/**
* lombok configuration: {@code checkerframework} = {@code true} | {@code false} | &lt;String: MajorVer.MinorVer&gt; (Default: false).
@@ -625,9 +625,9 @@ public class ConfigurationKeys {
* lombok configuration: {@code lombok.copyableAnnotations} += &lt;TypeName: fully-qualified annotation class name&gt;.
*
- * Copy these annotations to getters, setters, withers, builder-setters, etc.
+ * Copy these annotations to getters, setters, with methods, builder-setters, etc.
*/